[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --everything-is-local
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)


  * Table of Contents
    * [NOM](https://git-scm.com/docs/git/fr#_nom)
    * [SYNOPSIS](https://git-scm.com/docs/git/fr#_synopsis)
    * [DESCRIPTION](https://git-scm.com/docs/git/fr#_description)
    * [OPTIONS](https://git-scm.com/docs/git/fr#_options)
    * [COMMANDES GIT](https://git-scm.com/docs/git/fr#_commandes_git)
    * [Commandes de haut niveau (porcelaine)](https://git-scm.com/docs/git/fr#_commandes_de_haut_niveau_porcelaine)
    * [Commandes de bas niveau (plomberie)](https://git-scm.com/docs/git/fr#_commandes_de_bas_niveau_plomberie)
    * [Guides](https://git-scm.com/docs/git/fr#_guides)
    * [Interfaces de dépôt, de commande et de fichiers](https://git-scm.com/docs/git/fr#_interfaces_de_d%c3%a9p%c3%b4t_de_commande_et_de_fichiers)
    * [formats de fichiers, protocoles et interfaces de niveau développeur](https://git-scm.com/docs/git/fr#_formats_de_fichiers_protocoles_et_interfaces_de_niveau_d%c3%a9veloppeur)
    * [Mécanisme de configuration](https://git-scm.com/docs/git/fr#_m%c3%a9canisme_de_configuration)
    * [Terminologie des identifiants](https://git-scm.com/docs/git/fr#_terminologie_des_identifiants)
    * [Identificateurs symboliques](https://git-scm.com/docs/git/fr#_identificateurs_symboliques)
    * [Structure de fichier/répertoire](https://git-scm.com/docs/git/fr#_structure_de_fichierr%c3%a9pertoire)
    * [Terminologie](https://git-scm.com/docs/git/fr#_terminologie)
    * [Variables d’environnement](https://git-scm.com/docs/git/fr#_variables_denvironnement)
    * [Discussion]](https://git-scm.com/docs/git/fr#_discussion)
    * [SÉCURITÉ](https://git-scm.com/docs/git/fr#_s%c3%a9curit%c3%a9)
    * [DOCUMENTATION SUPPLÉMENTAIRE](https://git-scm.com/docs/git/fr#_documentation_suppl%c3%a9mentaire)
    * [Auteurs](https://git-scm.com/docs/git/fr#_auteurs)
    * [Signaler des bogues](https://git-scm.com/docs/git/fr#_signaler_des_bogues)
    * [VOIR AUSSI](https://git-scm.com/docs/git/fr#_voir_aussi)
    * [GIT](https://git-scm.com/docs/git/fr#_git)
    * [TRADUCTION](https://git-scm.com/docs/git/fr#_traduction)


[ Français ▾](https://git-scm.com/docs/git/fr)
Localized versions of **git** manual
  1. [English ](https://git-scm.com/docs/git)
  2. [Deutsch ](https://git-scm.com/docs/git/de)
  3. [Español ](https://git-scm.com/docs/git/es)
  4. [Français ](https://git-scm.com/docs/git/fr)
  5. [Português (Brasil) ](https://git-scm.com/docs/git/pt_BR)
  6. [Svenska ](https://git-scm.com/docs/git/sv)
  7. [українська мова ](https://git-scm.com/docs/git/uk)
  8. [简体中文 ](https://git-scm.com/docs/git/zh_HANS-CN)

Want to read in your language or fix typos?
[You can help translate this page](https://github.com/jnavila/git-manpages-l10n).
[Topics ▾](https://git-scm.com/docs/git/fr)
### Setup and Config
  * [ git ](https://git-scm.com/docs/git/fr)
  * [ config ](https://git-scm.com/docs/git-config/fr)
  * [ help ](https://git-scm.com/docs/git-help/fr)
  * [ bugreport ](https://git-scm.com/docs/git-bugreport/fr)
  * [ Credential helpers ](https://git-scm.com/doc/credential-helpers)


### Getting and Creating Projects
  * [ init ](https://git-scm.com/docs/git-init/fr)
  * [ clone ](https://git-scm.com/docs/git-clone/fr)


### Basic Snapshotting
  * [ add ](https://git-scm.com/docs/git-add/fr)
  * [ status ](https://git-scm.com/docs/git-status/fr)
  * [ diff ](https://git-scm.com/docs/git-diff/fr)
  * [ commit ](https://git-scm.com/docs/git-commit/fr)
  * [ notes ](https://git-scm.com/docs/git-notes/fr)
  * [ restore ](https://git-scm.com/docs/git-restore/fr)
  * [ reset ](https://git-scm.com/docs/git-reset/fr)
  * [ rm ](https://git-scm.com/docs/git-rm/fr)
  * [ mv ](https://git-scm.com/docs/git-mv/fr)


### Branching and Merging
  * [ branch ](https://git-scm.com/docs/git-branch/fr)
  * [ checkout ](https://git-scm.com/docs/git-checkout/fr)
  * [ switch ](https://git-scm.com/docs/git-switch/fr)
  * [ merge ](https://git-scm.com/docs/git-merge/fr)
  * [ mergetool ](https://git-scm.com/docs/git-mergetool/fr)
  * [ log ](https://git-scm.com/docs/git-log/fr)
  * [ stash ](https://git-scm.com/docs/git-stash/fr)
  * [ tag ](https://git-scm.com/docs/git-tag/fr)
  * [ worktree ](https://git-scm.com/docs/git-worktree/fr)


### Sharing and Updating Projects
  * [ fetch ](https://git-scm.com/docs/git-fetch/fr)
  * [ pull ](https://git-scm.com/docs/git-pull/fr)
  * [ push ](https://git-scm.com/docs/git-push/fr)
  * [ remote ](https://git-scm.com/docs/git-remote/fr)
  * [ submodule ](https://git-scm.com/docs/git-submodule/fr)


### Inspection and Comparison
  * [ show ](https://git-scm.com/docs/git-show/fr)
  * [ log ](https://git-scm.com/docs/git-log/fr)
  * [ diff ](https://git-scm.com/docs/git-diff/fr)
  * [ difftool ](https://git-scm.com/docs/git-difftool/fr)
  * [ range-diff ](https://git-scm.com/docs/git-range-diff/fr)
  * [ shortlog ](https://git-scm.com/docs/git-shortlog/fr)
  * [ describe ](https://git-scm.com/docs/git-describe/fr)


### Patching
  * [ apply ](https://git-scm.com/docs/git-apply/fr)
  * [ cherry-pick ](https://git-scm.com/docs/git-cherry-pick/fr)
  * [ diff ](https://git-scm.com/docs/git-diff/fr)
  * [ rebase ](https://git-scm.com/docs/git-rebase/fr)
  * [ revert ](https://git-scm.com/docs/git-revert/fr)


### Debugging
  * [ bisect ](https://git-scm.com/docs/git-bisect/fr)
  * [ blame ](https://git-scm.com/docs/git-blame/fr)
  * [ grep ](https://git-scm.com/docs/git-grep/fr)


### Email
  * [ am ](https://git-scm.com/docs/git-am/fr)
  * [ apply ](https://git-scm.com/docs/git-apply/fr)
  * [ imap-send ](https://git-scm.com/docs/git-imap-send/fr)
  * [ format-patch ](https://git-scm.com/docs/git-format-patch/fr)
  * [ send-email ](https://git-scm.com/docs/git-send-email/fr)
  * [ request-pull ](https://git-scm.com/docs/git-request-pull/fr)


### External Systems
  * [ svn ](https://git-scm.com/docs/git-svn)
  * [ fast-import ](https://git-scm.com/docs/git-fast-import/fr)


### Server Admin
  * [ daemon ](https://git-scm.com/docs/git-daemon/fr)
  * [ update-server-info ](https://git-scm.com/docs/git-update-server-info)


### Guides
  * [ gitattributes ](https://git-scm.com/docs/gitattributes)
  * [ Command-line interface conventions ](https://git-scm.com/docs/gitcli)
  * [ Everyday Git ](https://git-scm.com/docs/giteveryday)
  * [ Frequently Asked Questions (FAQ) ](https://git-scm.com/docs/gitfaq)
  * [ Glossary ](https://git-scm.com/docs/gitglossary/fr)
  * [ Hooks ](https://git-scm.com/docs/githooks)
  * [ gitignore ](https://git-scm.com/docs/gitignore/fr)
  * [ gitmodules ](https://git-scm.com/docs/gitmodules)
  * [ Revisions ](https://git-scm.com/docs/gitrevisions)
  * [ Submodules ](https://git-scm.com/docs/gitsubmodules)
  * [ Tutorial ](https://git-scm.com/docs/gittutorial)
  * [ Workflows ](https://git-scm.com/docs/gitworkflows)
  * [ All guides... ](https://git-scm.com/docs/git#_guides)


### Administration
  * [ clean ](https://git-scm.com/docs/git-clean/fr)
  * [ gc ](https://git-scm.com/docs/git-gc/fr)
  * [ fsck ](https://git-scm.com/docs/git-fsck/fr)
  * [ reflog ](https://git-scm.com/docs/git-reflog/fr)
  * [ filter-branch ](https://git-scm.com/docs/git-filter-branch)
  * [ instaweb ](https://git-scm.com/docs/git-instaweb/fr)
  * [ archive ](https://git-scm.com/docs/git-archive/fr)
  * [ bundle ](https://git-scm.com/docs/git-bundle/fr)


### Plumbing Commands
  * [ cat-file ](https://git-scm.com/docs/git-cat-file/fr)
  * [ check-ignore ](https://git-scm.com/docs/git-check-ignore/fr)
  * [ checkout-index ](https://git-scm.com/docs/git-checkout-index/fr)
  * [ commit-tree ](https://git-scm.com/docs/git-commit-tree/fr)
  * [ count-objects ](https://git-scm.com/docs/git-count-objects/fr)
  * [ diff-index ](https://git-scm.com/docs/git-diff-index)
  * [ for-each-ref ](https://git-scm.com/docs/git-for-each-ref)
  * [ hash-object ](https://git-scm.com/docs/git-hash-object)
  * [ ls-files ](https://git-scm.com/docs/git-ls-files)
  * [ ls-tree ](https://git-scm.com/docs/git-ls-tree)
  * [ merge-base ](https://git-scm.com/docs/git-merge-base)
  * [ read-tree ](https://git-scm.com/docs/git-read-tree)
  * [ rev-list ](https://git-scm.com/docs/git-rev-list/fr)
  * [ rev-parse ](https://git-scm.com/docs/git-rev-parse)
  * [ show-ref ](https://git-scm.com/docs/git-show-ref)
  * [ symbolic-ref ](https://git-scm.com/docs/git-symbolic-ref)
  * [ update-index ](https://git-scm.com/docs/git-update-index)
  * [ update-ref ](https://git-scm.com/docs/git-update-ref)
  * [ verify-pack ](https://git-scm.com/docs/git-verify-pack)
  * [ write-tree ](https://git-scm.com/docs/git-write-tree)


[ Latest version ▾ ](https://git-scm.com/docs/git/fr) git last updated in 2.53.0
Changes in the **git** manual
  1. [2.53.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2026-02-02_ ](https://git-scm.com/docs/git/2.53.0)
  2. [2.52.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-11-17_ ](https://git-scm.com/docs/git/2.52.0)
  3. 2.51.2 no changes
  4. [2.51.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-10-15_ ](https://git-scm.com/docs/git/2.51.1)
  5. 2.50.1 → 2.51.0 no changes
  6. [2.50.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-06-16_ ](https://git-scm.com/docs/git/2.50.0)
  7. 2.49.1 no changes
  8. [2.49.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-03-14_ ](https://git-scm.com/docs/git/2.49.0)
  9. 2.48.1 → 2.48.2 no changes
  10. [2.48.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-01-10_ ](https://git-scm.com/docs/git/2.48.0)
  11. 2.47.1 → 2.47.3 no changes
  12. [2.47.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-10-06_ ](https://git-scm.com/docs/git/2.47.0)
  13. 2.46.1 → 2.46.4 no changes
  14. [2.46.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-07-29_ ](https://git-scm.com/docs/git/2.46.0)
  15. 2.45.2 → 2.45.4 no changes
  16. [2.45.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-29_ ](https://git-scm.com/docs/git/2.45.1)
  17. [2.45.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-29_ ](https://git-scm.com/docs/git/2.45.0)
  18. 2.44.2 → 2.44.4 no changes
  19. [2.44.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.44.1)
  20. [2.44.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-02-23_ ](https://git-scm.com/docs/git/2.44.0)
  21. 2.43.5 → 2.43.7 no changes
  22. [2.43.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.43.4)
  23. 2.43.2 → 2.43.3 no changes
  24. [2.43.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-02-09_ ](https://git-scm.com/docs/git/2.43.1)
  25. [2.43.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-11-20_ ](https://git-scm.com/docs/git/2.43.0)
  26. 2.42.3 → 2.42.4 no changes
  27. [2.42.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.42.2)
  28. [2.42.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-11-02_ ](https://git-scm.com/docs/git/2.42.1)
  29. [2.42.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-08-21_ ](https://git-scm.com/docs/git/2.42.0)
  30. 2.41.2 → 2.41.3 no changes
  31. [2.41.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.41.1)
  32. [2.41.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-06-01_ ](https://git-scm.com/docs/git/2.41.0)
  33. 2.40.3 → 2.40.4 no changes
  34. [2.40.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.40.2)
  35. 2.40.1 no changes
  36. 2.40.0 no changes
  37. 2.39.5 no changes
  38. [2.39.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.39.4)
  39. 2.39.1 → 2.39.3 no changes
  40. [2.39.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-12-12_ ](https://git-scm.com/docs/git/2.39.0)
  41. 2.38.3 → 2.38.5 no changes
  42. [2.38.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-12-11_ ](https://git-scm.com/docs/git/2.38.2)
  43. 2.38.1 no changes
  44. [2.38.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-10-02_ ](https://git-scm.com/docs/git/2.38.0)
  45. 2.37.3 → 2.37.7 no changes
  46. [2.37.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-08-11_ ](https://git-scm.com/docs/git/2.37.2)
  47. 2.37.1 no changes
  48. [2.37.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-06-27_ ](https://git-scm.com/docs/git/2.37.0)
  49. 2.36.1 → 2.36.6 no changes
  50. [2.36.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-04-18_ ](https://git-scm.com/docs/git/2.36.0)
  51. 2.35.1 → 2.35.8 no changes
  52. [2.35.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-01-24_ ](https://git-scm.com/docs/git/2.35.0)
  53. 2.34.1 → 2.34.8 no changes
  54. [2.34.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-11-15_ ](https://git-scm.com/docs/git/2.34.0)
  55. 2.33.3 → 2.33.8 no changes
  56. [2.33.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-03-23_ ](https://git-scm.com/docs/git/2.33.2)
  57. [2.33.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-10-12_ ](https://git-scm.com/docs/git/2.33.1)
  58. 2.32.1 → 2.33.0 no changes
  59. [2.32.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-06-06_ ](https://git-scm.com/docs/git/2.32.0)
  60. 2.31.1 → 2.31.8 no changes
  61. [2.31.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-03-15_ ](https://git-scm.com/docs/git/2.31.0)
  62. 2.30.1 → 2.30.9 no changes
  63. [2.30.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-12-27_ ](https://git-scm.com/docs/git/2.30.0)
  64. 2.29.1 → 2.29.3 no changes
  65. [2.29.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-10-19_ ](https://git-scm.com/docs/git/2.29.0)
  66. 2.28.1 no changes
  67. [2.28.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-07-27_ ](https://git-scm.com/docs/git/2.28.0)
  68. 2.27.1 no changes
  69. [2.27.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-06-01_ ](https://git-scm.com/docs/git/2.27.0)
  70. 2.26.1 → 2.26.3 no changes
  71. [2.26.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-03-22_ ](https://git-scm.com/docs/git/2.26.0)
  72. 2.25.2 → 2.25.5 no changes
  73. [2.25.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-02-17_ ](https://git-scm.com/docs/git/2.25.1)
  74. [2.25.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-01-13_ ](https://git-scm.com/docs/git/2.25.0)
  75. 2.23.1 → 2.24.4 no changes
  76. [2.23.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-08-16_ ](https://git-scm.com/docs/git/2.23.0)
  77. 2.22.2 → 2.22.5 no changes
  78. [2.22.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-08-11_ ](https://git-scm.com/docs/git/2.22.1)
  79. [2.22.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-06-07_ ](https://git-scm.com/docs/git/2.22.0)
  80. 2.20.1 → 2.21.4 no changes
  81. [2.20.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-12-09_ ](https://git-scm.com/docs/git/2.20.0)
  82. 2.19.3 → 2.19.6 no changes
  83. [2.19.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-11-21_ ](https://git-scm.com/docs/git/2.19.2)
  84. 2.19.1 no changes
  85. [2.19.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-09-10_ ](https://git-scm.com/docs/git/2.19.0)
  86. 2.18.1 → 2.18.5 no changes
  87. [2.18.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-06-21_ ](https://git-scm.com/docs/git/2.18.0)
  88. 2.17.1 → 2.17.6 no changes
  89. [2.17.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-04-02_ ](https://git-scm.com/docs/git/2.17.0)
  90. [2.16.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-12-06_ ](https://git-scm.com/docs/git/2.16.6)
  91. [2.15.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-12-06_ ](https://git-scm.com/docs/git/2.15.4)
  92. [2.14.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-12-06_ ](https://git-scm.com/docs/git/2.14.6)
  93. 2.13.7 no changes
  94. [2.12.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/git/2.12.5)
  95. [2.11.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/git/2.11.4)
  96. [2.10.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/git/2.10.5)
  97. [2.9.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git/2.9.5)
  98. [2.8.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git/2.8.6)
  99. [2.7.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git/2.7.6)
  100. [2.6.7 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-05-05_ ](https://git-scm.com/docs/git/2.6.7)
  101. [2.5.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-05-05_ ](https://git-scm.com/docs/git/2.5.6)
  102. [2.4.12 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-05-05_ ](https://git-scm.com/docs/git/2.4.12)
  103. [2.3.10 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2015-09-28_ ](https://git-scm.com/docs/git/2.3.10)
  104. [2.2.3 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2015-09-04_ ](https://git-scm.com/docs/git/2.2.3)
  105. [2.1.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2014-12-17_ ](https://git-scm.com/docs/git/2.1.4)
  106. [2.0.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2014-12-17_ ](https://git-scm.com/docs/git/2.0.5)


Check your version of git by running
`git --version`
##  [](https://git-scm.com/docs/git/fr#_nom)NOM
git - le traqueur de contenu stupide
##  [](https://git-scm.com/docs/git/fr#_synopsis)SYNOPSIS
```
_git_ [-v | --version] [-h | --help] [-C <chemin>] [-c <nom>=<valeur>]
    [--exec-path[=<chemin>]] [--html-path] [--man-path] [--info-path]
    [-p | --paginate | -P | --no-pager] [--no-replace-objects]  [--no-lazy-fetch]
    [--no-optional-locks] [--no-advice] [--bare]
    [--git-dir=<chemin>] [--work-tree=<chemin>] [--namespace=<nom>]
    [--config-env=<nom>=<var-env>] <commande> [<args>]
```

##  [](https://git-scm.com/docs/git/fr#_description)DESCRIPTION
Git est un système de gestion de révision rapide, extensible et distribué avec un ensemble de commandes inhabituellement riche qui fournit à la fois des opérations de haut niveau et un accès complet aux structures de bas niveau.
Voir [gittutorial[7]](https://git-scm.com/docs/gittutorial/fr) pour démarrer, puis voir [giteveryday[7]](https://git-scm.com/docs/giteveryday/fr) pour un ensemble minimal utile de commandes. Le [manuel utilisateur de Git](https://git-scm.com/docs/user-manual/fr) contient une introduction plus approfondie.
Aprs avoir maîtrisé les concepts de base, vous pouvez revenir à cette page pour apprendre les commandes que Git offre. Vous pouvez en apprendre plus sur chaque commande Git avec « git help command ». La page de manuel de [gitcli[7]](https://git-scm.com/docs/gitcli/fr) fournit un aperçu de la syntaxe de commande de la ligne de commande.
Une copie formatée et hyperliée de la dernière documentation de Git peut être visualisée à <https://git.github.io/htmldocs/git.html> ou à <https://git-scm.com/docs>.
##  [](https://git-scm.com/docs/git/fr#_options)OPTIONS

[](https://git-scm.com/docs/git/fr#git--v)-v


[](https://git-scm.com/docs/git/fr#git---version)--version

Afficher la version de la suite Git de laquelle le programme _git_ provient.
Cette option est convertie en interne en `git` `version...` et accepte les mêmes options que la commande [git-version[1]](https://git-scm.com/docs/git-version/fr). Si l’on `--help` est donnée aussi , elle a préséance sur `--version`.

[](https://git-scm.com/docs/git/fr#git--h)-h


[](https://git-scm.com/docs/git/fr#git---help)--help

Afficher le synopsis et les liste des commandes les plus utilisées. Si l’option `--all` ou `-a` est fournie alors toutes les commandes disponibles sont affichées. si une commande Git est fournie, cette option affiche la page de manuel pour cette commande.
Les autres options sont disponibles pour contrôler comment la page de manuel est affichée. Voir [git-help[1]](https://git-scm.com/docs/git-help/fr) pour plus d’information, parce que `git` `--help` ... est convertie en interne en `git` `help` ....

[](https://git-scm.com/docs/git/fr#git--Cchemin) [](https://git-scm.com/docs/git/fr#git--Cltchemingt)-C <chemin>

Démarrer comme si git était lancé depuis _< chemin>_ au lieu du répertoire de travail actuel. Quand plusieurs options `-C` sont fournies, chaque `-C` _< chemin>_ non-absolu supplémentaire est interprété relativement au `-C` _< chemin>_ précédent. Si _< chemin>_ est présent mais vide, c-à-d `-C` `""`, alors le répertoire de travail courant est laissé inchangé.
Cette option affecte les options qui attendent de chemins comme `--git-dir` et `--work-tree` en ce que leurs interprétations des noms de chemins seront relatives au répertoire de travail défini par l’option `-C`. Par exemple, les invocations suivantes sont équivalentes :
```
git --git-dir=a.git --work-tree=b -C c status
git --git-dir=c/a.git --work-tree=c/b status
```


[](https://git-scm.com/docs/git/fr#git--cnomvaleur) [](https://git-scm.com/docs/git/fr#git--cltnomgtltvaleurgt)-c <nom>=<valeur>

Passer un paramètre de configuration à la commande. La valeur fournie surchargera la valeur des fichiers des configuration. Le <nom> a le même format que listé par ‘git config’ (sous-clés séparées par des points).
Notez qu’omettre le `=` dans `git` `-c` `foo.bar` ... est permis et positionne `foo.bar` à la valeur booléenne true (de la même manière que le ferait [`foo`]`bar` dans un fichier de configuration). Si le `=` est inclus mais avec une valeur vide (comme `git` `-c` `foo.bar=` ...), cela positionne `foo.bar` à la chaîne vide que `git` `config` `--type=bool` convertira en `false`.

[](https://git-scm.com/docs/git/fr#git---config-envnomvar-env) [](https://git-scm.com/docs/git/fr#git---config-envltnomgtltvar-envgt)--config-env=<nom>=<var-env>

À l’instar de `-c` _< nom>_`=`_< valeur>_, donner une valeur à la variable de configuration _< nom>_, où <envvar> est le nom d’une variable d’environnement depuis laquelle récupérer la valeur. Contrairement à `-c` il n’y a pas de raccourci pour définir directement la valeur à une chaîne vide, la variable d’environnement elle-même doit être définie à la chaîne vide. Il s’agit d’une erreur si le `envvar` n’existe pas dans l’environnement. _< envvar>_ ne peut pas contenir un signe égal pour éviter toute ambiguïté avec _< nom>_ en contenant un.
Ceci est utile pour les cas où vous voulez passer des options de configuration transitoires à git, mais le faire sur les systèmes d’exploitation où d’autres processus pourraient être en mesure de lire votre ligne de commande (par exemple `/proc/self/cmdline`), mais pas votre environnement (par exemple `/proc/self/environ`). C’est le comportement par défaut sur Linux, mais peut ne pas l’être sur votre système.
Notez que cela pourrait ajouter de la sécurité pour des variables telles que `http.extraHeader` où les informations sensibles font partie de la valeur, mais pas par exemple `url.` _< base>_`.insteadOf` où les informations sensibles peuvent faire partie de la clé.

[](https://git-scm.com/docs/git/fr#git---exec-pathchemin) [](https://git-scm.com/docs/git/fr#git---exec-pathltchemingt)--exec-path[=<chemin>]

Chemin dans lequel les programmes de base de Git sont installés. Cela peut aussie être géré en positionnant la variable d’environnement GIT_EXEC_PATH. Si aucun chemin n’est spécifié, _git_ affichera la valeur actuelle, puis sortira.

[](https://git-scm.com/docs/git/fr#git---html-path)--html-path

Afficher le chemin, sans la barre finale, où la documentation HTML de Git est installé et sortir.

[](https://git-scm.com/docs/git/fr#git---man-path)--man-path

Afficher le chemin manpath (voir `man`(`1`)) pour les pages de manuel de cette version de Git et sortir.

[](https://git-scm.com/docs/git/fr#git---info-path)--info-path

Afficher le chemin où sont installés les fichiers Info documentant cette version de Git et sortir.

[](https://git-scm.com/docs/git/fr#git--p)-p


[](https://git-scm.com/docs/git/fr#git---paginate)--paginate

Redirige toutes les sorties dans _less_ (ou $PAGER, si positionné) si la sortie standard est un terminal. Cela surcharge les options de configuration `pager.`_< cmd>_ (voir la section « Mécanisme de configuration » ci-dessous).

[](https://git-scm.com/docs/git/fr#git--P)-P


[](https://git-scm.com/docs/git/fr#git---no-pager)--no-pager

Ne pas rediriger la sortie de Git dans un pageur.

[](https://git-scm.com/docs/git/fr#git---git-dirchemin) [](https://git-scm.com/docs/git/fr#git---git-dirltchemingt)--git-dir=<chemin>

Règle le chemin vers le dépôt (répertoire ".git"). Ceci peut aussi être contrôlé en réglant la variable d’environnement `GIT_DIR`. Ce peut être un chemin absolu ou relatif au répertoire de travail actuel.
Spécifier l’emplacement du répertoire ".git" en utilisant cette option (ou la variable d’environnement `GIT_DIR`) désactive la découverte de dépôt, qui tente de trouver un répertoire avec un sous-répertoire ".git" (ce qui est la façon dont le dépôt et le niveau supérieur de l’arbre de travail sont découverts), et indique à Git que vous êtes au niveau supérieur de l’arbre de travail. Si vous n’êtes pas dans le répertoire de niveau supérieur de l’arbre de travail, vous devez dire à Git où se trouve le niveau supérieur de l’arbre de travail, avec l’option `--work-tree=`_< chemin>_ (`ou` `la` `variable` `d'environnement``GIT_WORK_TREE`)
Si vous voulez juste lancer git comme s’il était démarré dans _< chemin>_, utilisez `git` `-C` _< chemin>_.

[](https://git-scm.com/docs/git/fr#git---work-treechemin) [](https://git-scm.com/docs/git/fr#git---work-treeltchemingt)--work-tree=<chemin>

Régler le chemin du répertoire de travail. Ce peut être un chemin absolu ou un chemin relatif au répertoire de travail actuel. Ceci peut aussi être contrôlé en réglant la variable d’environnement GIT_WORK_TREE et la variable de configuration core.worktree (voir core.worktree dans [git-config[1]](https://git-scm.com/docs/git-config/fr) pour une discussion plus détaillée).

[](https://git-scm.com/docs/git/fr#git---namespacechemin) [](https://git-scm.com/docs/git/fr#git---namespaceltchemingt)--namespace=<chemin>

Régler l’espace de nommage Git. Voir [gitnamespaces[7]](https://git-scm.com/docs/gitnamespaces/fr) pour plus de détails. Équivalent à régler la variable d’environnement `GIT_NAMESPACE`.

[](https://git-scm.com/docs/git/fr#git---bare)--bare

Traiter le dépôt comme un dépôt nu. Si l’environnement `GIT_DIR` n’est pas défini, alors il est défini au répertoire de travail actuel.

[](https://git-scm.com/docs/git/fr#git---no-replace-objects)--no-replace-objects

Ne pas utiliser des refs de remplacement pour remplacer des objets Git. Voir [git-replace[1]](https://git-scm.com/docs/git-replace/fr) pour de plus amples informations. Ceci équivaut à l’exportation de la variable d’environnement `GIT_NO_REPLACE_OBJECTS` avec n’importe quelle valeur. Voir [git-replace[1]](https://git-scm.com/docs/git-replace/fr) pour de plus amples d’informations.

[](https://git-scm.com/docs/git/fr#git---no-lazy-fetch)--no-lazy-fetch

Do not fetch missing objects from the promisor remote on demand. Useful together with `git` `cat-file` `-e` _< object>_ to see if the object is locally available. This is equivalent to setting the `GIT_NO_LAZY_FETCH` environment variable to `1`.

[](https://git-scm.com/docs/git/fr#git---no-optional-locks)--no-optional-locks

Ne pas effectuer des opérations optionnelles qui nécessitent des verrouillages. Ceci équivaut à mettre `GIT_OPTIONAL_LOCKS` à `0`.

[](https://git-scm.com/docs/git/fr#git---no-advice)--no-advice

Disable all advice hints from being printed.

[](https://git-scm.com/docs/git/fr#git---literal-pathspecs)--literal-pathspecs

Traier les spécificateurs de chemins littéralement (c-à-d sans jokers ni magie de pathspec). Ceci est équivalent à régler la variable d’environnement `GIT_LITERAL_PATHSPECS` à `1`.

[](https://git-scm.com/docs/git/fr#git---glob-pathspecs)--glob-pathspecs

Ajouter la magie « glob » à tous les spécificateurs de chemin. C’est équivalent à régler la variable d’environnement `GIT_GLOB_PATHSPECS` à `1`. La désactivation du traitement glob sur des spécificateurs de chemin spécifiques peut être réalisée en utilisant le préfixe magique ":(litera)"

[](https://git-scm.com/docs/git/fr#git---noglob-pathspecs)--noglob-pathspecs

Ajouter la magie « literal » à tous les spécificateurs de chemin. C’est équivalent à régler la variable d’environnement `GIT_NOGLOB_PATHSPECS` à `1`. L’activation du traitement glob sur des spécificateurs de chemin spécifiques peut être réalisée en utilisant le préfixe magique ":(glob)"

[](https://git-scm.com/docs/git/fr#git---icase-pathspecs)--icase-pathspecs

Ajouter la magie « icase » à tous les spécificateurs de chemin. C’est équivalent à régler la variable d’environnement `GIT_ICASE_PATHSPECS` à `1`.

[](https://git-scm.com/docs/git/fr#git---list-cmdsgroupegroupe) [](https://git-scm.com/docs/git/fr#git---list-cmdsltgroupegtltgroupegt82308203)--list-cmds=<groupe>[,<groupe>…​]

Liste les commandes par groupe. Il s’agit d’une option interne/expérimentale et peut changer ou être retirée à l’avenir. Les groupes pris en charge sont les suivants : builtins, parseopt (commandes intégrées qui utilisent parse-options), deprecated (commandes intégrées obsolètes), main (toutes commandes dans le répertoire libexec), autres (toutes autres commandes dans `$PATH` qui ont un préfixe git), list-<catégorie> (voir les catégories dans command-list.txt), nohelpers (exclure les commandes assistantes), alias et config (récupère la liste de commandes depuis la variable de configuration completion.commands)

[](https://git-scm.com/docs/git/fr#git---attr-sourcearbre-esque) [](https://git-scm.com/docs/git/fr#git---attr-sourceltarbre-esquegt)--attr-source=<arbre-esque>

Lire les gitattributs depuis <arbre-esque> au lieu de l’arbre-de-travail. Voir [gitattributes[5]](https://git-scm.com/docs/gitattributes/fr). C’est équivalent à régler la variable d’environnement `GIT_ATTR_SOURCE`.
##  [](https://git-scm.com/docs/git/fr#_commandes_git)COMMANDES GIT
Nous divisons Git entre les commandes de haut niveau ("porcelaine") et de bas niveau ("plomberie").
##  [](https://git-scm.com/docs/git/fr#_commandes_de_haut_niveau_porcelaine)Commandes de haut niveau (porcelaine)
Nous séparerons les commandes de porcelaine entre commandes principales et quelques utilitaires auxiliaires.
###  [](https://git-scm.com/docs/git/fr#_commandes_porcelaine_principales)Commandes Porcelaine Principales
Warning |  Missing `fr/{build_dir}/cmds-mainporcelain.adoc` See original version for this content.
---|---
###  [](https://git-scm.com/docs/git/fr#_commandes_auxiliaires)Commandes auxiliaires
Manipulateurs :
Warning |  Missing `fr/{build_dir}/cmds-ancillarymanipulators.adoc` See original version for this content.
---|---
Interrogateurs :
Warning |  Missing `fr/{build_dir}/cmds-ancillaryinterrogators.adoc` See original version for this content.
---|---
###  [](https://git-scm.com/docs/git/fr#_interaction_avec_dautres_d%C3%A9veloppeurs)Interaction avec d’autres développeurs
Ces commandes permettent d’interagir avec autre SCM et avec d’autres personnes via rustines envoyées par courriel.
Warning |  Missing `fr/{build_dir}/cmds-foreignscminterface.adoc` See original version for this content.
---|---
###  [](https://git-scm.com/docs/git/fr#_r%C3%A9initialiser_restaurer_et_revenir)Réinitialiser, restaurer et revenir
Il y a trois commandes avec des noms similaires : `git` `reset`, `git` `restore` et `git` `revert`.
  * [git-revert[1]](https://git-scm.com/docs/git-revert/fr) sert à faire un nouveau commit qui inverse les modifications apportées par d’autres commits.
  * [git-restore[1]](https://git-scm.com/docs/git-restore/fr) consiste à restaurer des fichiers dans l’arbre de travail à partir de l’index ou d’un autre commit. Cette commande ne met pas à jour votre branche. La commande peut également être utilisée pour restaurer des fichiers dans l’index depuis un autre commit.
  * [git-reset[1]](https://git-scm.com/docs/git-reset/fr) consiste à mettre à jour votre branche, en déplaçant le sommet afin d’ajouter ou de supprimer des commits de la branche. Cette opération modifie l’historique des commits.
`git` `reset` peut également être utilisé pour restaurer l’index, à la manière de `git` `restore`.


##  [](https://git-scm.com/docs/git/fr#_commandes_de_bas_niveau_plomberie)Commandes de bas niveau (plomberie)
Bien que Git comprend sa propre couche de porcelaine, ses commandes de bas niveau sont suffisantes pour développer de porcelaines alternatives. Les développeurs de ces porcelaines devraient commencer par la lecture de [git-update-index[1]](https://git-scm.com/docs/git-update-index/fr) et [git-read-tree[1]](https://git-scm.com/docs/git-read-tree/fr).
L’interface (entrée, sortie, ensemble d’options et sémantique) à ces commandes de bas niveau est censée être beaucoup plus stable que les commandes de niveau Porcelaine, parce que ces commandes sont principalement destinées à une utilisation scriptée. L’interface des commandes Porcelaine en revanche est sujette à changement afin d’améliorer l’expérience de l’utilisateur final.
La description suivante divise les commandes de bas niveau en commandes qui manipulent les objets (dans le dépôt, l’index et l’arbre de travail), celles qui interrogent et comparent les objets, et les commandes qui déplacent les objets et les références entre les dépôts.
###  [](https://git-scm.com/docs/git/fr#_commandes_de_manipulation)Commandes de manipulation
Warning |  Missing `fr/{build_dir}/cmds-plumbingmanipulators.adoc` See original version for this content.
---|---
###  [](https://git-scm.com/docs/git/fr#_commandes_dinterrogation)Commandes d’interrogation
Warning |  Missing `fr/{build_dir}/cmds-plumbinginterrogators.adoc` See original version for this content.
---|---
En général, les commandes d’interrogation ne modifient pas les fichiers dans l’arbre de travail.
###  [](https://git-scm.com/docs/git/fr#_synchronisation_des_d%C3%A9p%C3%B4ts)Synchronisation des dépôts
Warning |  Missing `fr/{build_dir}/cmds-synchingrepositories.adoc` See original version for this content.
---|---
Les commandes suivantes sont des utilitaires utilisés par celles ci-dessus ; les utilisateurs finaux ne les utilisent généralement pas directement.
Warning |  Missing `fr/{build_dir}/cmds-synchelpers.adoc` See original version for this content.
---|---
###  [](https://git-scm.com/docs/git/fr#_commandes_assistantes_internes)Commandes assistantes internes
Ce sont des commandes assistantes internes utilisées par d’autres commandes ; les utilisateurs finaux ne les utilisent généralement pas directement.
Warning |  Missing `fr/{build_dir}/cmds-purehelpers.adoc` See original version for this content.
---|---
##  [](https://git-scm.com/docs/git/fr#_guides)Guides
Les pages de documentation suivantes sont des guides sur les concepts Git.
Warning |  Missing `fr/{build_dir}/cmds-guide.adoc` See original version for this content.
---|---
##  [](https://git-scm.com/docs/git/fr#_interfaces_de_d%C3%A9p%C3%B4t_de_commande_et_de_fichiers)Interfaces de dépôt, de commande et de fichiers
Cette documentation traite des interfaces de dépôt et de commande que les utilisateurs sont censés utiliser directement. Pour plus de détails sur les critères, consultez `--user-formats` dans [git-help[1]](https://git-scm.com/docs/git-help/fr).
Warning |  Missing `fr/{build_dir}/cmds-userinterfaces.adoc` See original version for this content.
---|---
##  [](https://git-scm.com/docs/git/fr#_formats_de_fichiers_protocoles_et_interfaces_de_niveau_d%C3%A9veloppeur)formats de fichiers, protocoles et interfaces de niveau développeur
Cette documentation traite des formats de fichiers, des protocoles de communication et d’autres interfaces pour les développeur de git. Voir `--developer-interfaces` dans [git-help[1]](https://git-scm.com/docs/git-help/fr).
Warning |  Missing `fr/{build_dir}/cmds-developerinterfaces.adoc` See original version for this content.
---|---
##  [](https://git-scm.com/docs/git/fr#_m%C3%A9canisme_de_configuration)Mécanisme de configuration
Git utilise un format texte simple pour stocker les personnalisations qui sont spécifique au dépôt et à l’utilisateur. Un tel fichier de configuration peut ressembler à ceci :
```
#
# Un caractère A '#' ou ';' indique un commentaire.
#

; variables de base
[core]
	; ne pas faire confiance au mode des fichiers
	filemode = false

; identité de l'utilisateur
[user]
	name = "Junio C Hamano"
	email = "gitster@pobox.com"
```

Diverses commandes lisent le fichier de configuration et modifient leur comportement en conséquence. Voir [git-config[1]](https://git-scm.com/docs/git-config/fr) pour une liste et plus de détails sur le mécanisme de configuration.
##  [](https://git-scm.com/docs/git/fr#_terminologie_des_identifiants)Terminologie des identifiants

[](https://git-scm.com/docs/git/fr#git-objet) [](https://git-scm.com/docs/git/fr#git-ltobjetgt)<objet>

Indique le nom de l’objet pour tout type d’objet.

[](https://git-scm.com/docs/git/fr#git-blob) [](https://git-scm.com/docs/git/fr#git-ltblobgt)<blob>

Indique un nom d’objet blob.

[](https://git-scm.com/docs/git/fr#git-arbre) [](https://git-scm.com/docs/git/fr#git-ltarbregt)<arbre>

Indique un nom d’objet d’arbre.

[](https://git-scm.com/docs/git/fr#git-commit) [](https://git-scm.com/docs/git/fr#git-ltcommitgt)<commit>

Indique un nom d’objet commit.

[](https://git-scm.com/docs/git/fr#git-arbre-esque) [](https://git-scm.com/docs/git/fr#git-ltarbre-esquegt)<arbre-esque>

Indique un nom d’objet arbre, commit ou étiquette. Une commande qui prend un argument <arbre-esque> veut finalement opérer sur un objet <arbre> mais déréférences automatiquement les objets <commit> et <étiquette> qui pointent sur un <arbre>.

[](https://git-scm.com/docs/git/fr#git-commit-esque) [](https://git-scm.com/docs/git/fr#git-ltcommit-esquegt)<commit-esque>

Indique un nom d’objet commit ou étiquette. Une commande qui prend un argument <commit-esque> veut ultimement opérer sur un objet <commit>, mais déréférence automatiquement des objets <étiquette> qui pointent sur un <commit>.

[](https://git-scm.com/docs/git/fr#git-type) [](https://git-scm.com/docs/git/fr#git-lttypegt)<type>

Indique qu’un type d’objet est requis. Actuellement, soit`blob`, `arbre`, `commit`, ou _étiquette_.

[](https://git-scm.com/docs/git/fr#git-fichier) [](https://git-scm.com/docs/git/fr#git-ltfichiergt)<fichier>

Indique un nom de fichier - presque toujours relatif à la racine de la structure de l’arbre que`GIT_INDEX_FILE` décrit.
##  [](https://git-scm.com/docs/git/fr#_identificateurs_symboliques)Identificateurs symboliques
Toute commande Git acceptant n’importe quel <objet> peut également utiliser la notation symbolique suivante :

[](https://git-scm.com/docs/git/fr#git-HEAD)HEAD

indique la tête de la branche actuelle.

[](https://git-scm.com/docs/git/fr#git-tiquette) [](https://git-scm.com/docs/git/fr#git-lttiquettegt)<étiquette>

un _nom_ valide d’étiquette (c.-à-d. une référence `refs/tags/`_< étiquette>_).

[](https://git-scm.com/docs/git/fr#git-tte) [](https://git-scm.com/docs/git/fr#git-ltttegt)<tête>

un _nom_ valide de tête (c.-à-d. une référence `refs/heads/`_< tête>_).
Pour une liste plus complète des façons d’épeler les noms d’objets, voir la section « SPÉCIFICATION DE RÉVISIONS" dans [gitrevisions[7]](https://git-scm.com/docs/gitrevisions/fr).
##  [](https://git-scm.com/docs/git/fr#_structure_de_fichierr%C3%A9pertoire)Structure de fichier/répertoire
Veuillez consulter le document [gitrepository-layout[5]](https://git-scm.com/docs/gitrepository-layout/fr).
Lire [githooks[5]](https://git-scm.com/docs/githooks/fr) pour plus de détails sur chaque crochet.
Les SCM de niveau supérieur peuvent fournir et gérer des informations supplémentaires dans le `$GIT_DIR`.
##  [](https://git-scm.com/docs/git/fr#_terminologie)Terminologie
Veuillez consulter [gitglossary[7]](https://git-scm.com/docs/gitglossary/fr).
##  [](https://git-scm.com/docs/git/fr#_variables_denvironnement)Variables d’environnement
Diverses commandes Git sont sensibles aux variables d’environnement et modifient leur comportement. Les variables d’environnement marquées comme "Booléenne" prennent leurs valeurs de la même manière que les variables de configuration évaluées comme Booléenne, p.ex. `true`, `yes`, `on` et les chiffres positifs sont pris comme `yes`, tandis que `false`, `no`, `off`, and `0` sont pris comme `no`.
Voici les variables :
###  [](https://git-scm.com/docs/git/fr#_syst%C3%A8me)Système

[](https://git-scm.com/docs/git/fr#git-HOME) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeHOMEcodespan)`HOME`

Specifies the path to the user’s home directory. On Windows, if unset, Git will set a process environment variable equal to: `$HOMEDRIVE$HOMEPATH` if both `$HOMEDRIVE` and `$HOMEPATH` exist; otherwise `$USERPROFILE` if `$USERPROFILE` exists.
###  [](https://git-scm.com/docs/git/fr#_le_d%C3%A9p%C3%B4t_git)Le dépôt Git
Ces variables d’environnement s’appliquent à _toutes_ les commandes du cœur de Git. Nb : il est intéressant de noter qu’elles peuvent être utilisées/surchargées par les SCMS agissant par-dessus Git alors faites attention si vous utilisez un frontal externe.

[](https://git-scm.com/docs/git/fr#git-GITINDEXFILE) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITINDEXFILEcodespan)`GIT_INDEX_FILE`

Cette variable d’environnement spécifie un fichier d’index alternatif. Si elle n’est pas spécifiée, la valeur par défaut `$GIT_DIR/index` est utilisée.

[](https://git-scm.com/docs/git/fr#git-GITINDEXVERSION) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITINDEXVERSIONcodespan)`GIT_INDEX_VERSION`

Cette variable d’environnement spécifie quelle version index est utilisée lors de l’écriture du fichier index. Il n’affectera pas les fichiers d’index existants. Par défaut index version 2 ou 3 est utilisé. Voir [git-update-index[1]](https://git-scm.com/docs/git-update-index/fr) pour plus d’informations.

[](https://git-scm.com/docs/git/fr#git-GITOBJECTDIRECTORY) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITOBJECTDIRECTORYcodespan)`GIT_OBJECT_DIRECTORY`

Si le répertoire de stockage d’objets est spécifié via cette variable d’environnement, alors les répertoires sha1 sont créés dedans - sinon le répertoire par défaut `$GIT_DIR/objects` est utilisé.

[](https://git-scm.com/docs/git/fr#git-GITALTERNATEOBJECTDIRECTORIES) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITALTERNATEOBJECTDIRECTORIEScodespan)`GIT_ALTERNATE_OBJECT_DIRECTORIES`

En raison de la nature immuable des objets Git, de vieux objets peuvent être archivés dans des répertoires partagés en lecture seule. Cette variable spécifie une liste avec ":" pour séparateur (";" sur Windows) des répertoires d’objets Git qui peuvent être utilisés pour rechercher des objets Git. Aucun nouvel objet ne sera écrit dans ces répertoires.
Les entrées qui commencent par `"` (double-guillemets) seront interprétées comme des chemins cités de type C, en éliminant les guillemets et les doubles guillemets et en respectant les échappements par barre oblique inverse. Par exemple, la valeur _"chemin-avec-\"-et-:-a-l-interieur":chemin-simple_ a deux chemins : `chemin-avec-"-et-:-a-l-interieur` et `chemin-simple`.

[](https://git-scm.com/docs/git/fr#git-GITDIR) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITDIRcodespan)`GIT_DIR`

Si la variable d’environnement _GIT_DIR' est définie, elle spécifie un chemin à utiliser au lieu de `.git_ par défaut pour la base du dépôt. L’option de ligne de commande `--git-dir` définit également cette valeur.

[](https://git-scm.com/docs/git/fr#git-GITWORKTREE) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITWORKTREEcodespan)`GIT_WORK_TREE`

Régler le chemin vers la racine de l’arbre de travail. Cela peut également être contrôlé par l’option de ligne de commande `--work-tree` et la variable de configuration de core.worktree.

[](https://git-scm.com/docs/git/fr#git-GITNAMESPACE) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITNAMESPACEcodespan)`GIT_NAMESPACE`

Définir l’espace de nom Git ; voir [gitnamespaces[7]](https://git-scm.com/docs/gitnamespaces/fr) pour plus de détails. L’option de ligne de commande `--namespace` définit également cette valeur.

[](https://git-scm.com/docs/git/fr#git-GITCEILINGDIRECTORIES) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITCEILINGDIRECTORIEScodespan)`GIT_CEILING_DIRECTORIES`

Cela devrait être une liste des chemins absolus séparés par des caractères deux point. Si elle est définie, il s’agit d’une liste de répertoires que Git ne devrait pas visiter pendant la recherche d’un répertoire de dépôt (utile pour exclure les répertoires sur réseau lents). Elle n’exclura pas le répertoire de travail actuel ou un GIT_DIR indiqué sur la ligne de commande ou dans l’environnement. Normalement, Git doit lire les entrées dans cette liste et résoudre tout lien symbolique qui pourrait être présent pour les comparer avec le répertoire courant. Cependant, si même cet accès est lent, vous pouvez ajouter une entrée vide à la liste pour dire à Git que les entrées subséquentes ne sont pas des liens symboliques et ne doivent pas être résolues ; par exemple, `GIT_CEILING_DIRECTORIES=/peutetre/symlink://non/symlink/mais/lent`.

[](https://git-scm.com/docs/git/fr#git-GITDISCOVERYACROSSFILESYSTEM) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITDISCOVERYACROSSFILESYSTEMcodespan)`GIT_DISCOVERY_ACROSS_FILESYSTEM`

Lorsque Git se trouve dans un répertoire qui n’a pas de répertoire ".git", Git tente de trouver un tel répertoire dans les répertoires parent pour trouver le sommet de l’arbre de travail, mais par défaut il ne dépasse pas les limites du système de fichiers actuel. Cette variable d’environnement Booléenne peut être définie à true pour dire à Git de ne pas s’arrêter aux limites des systèmes de fichiers. Comme `GIT_CEILING_DIRECTORIES`, cela n’affectera pas un répertoire de dépôt explicite indiqué via `GIT_DIR` ou sur la ligne de commande.

[](https://git-scm.com/docs/git/fr#git-GITCOMMONDIR) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITCOMMONDIRcodespan)`GIT_COMMON_DIR`

Si cette variable est définie comme un chemin, les fichiers hos de l’arbre-de-travail qui sont normalement dans $GIT_DIR seront pris depuis ce chemin à la place. Les fichiers spécifiques à des arbres-de-travail tels que HEAD ou index sont extraits de $GIT_DIR. Voir [gitrepository-layout[5]](https://git-scm.com/docs/gitrepository-layout/fr) et [git-worktree[1]](https://git-scm.com/docs/git-worktree/fr) pour plus de détails. Cette variable a une préséance inférieure à d’autres variables de chemin comme GIT_INDEX_FILE, GIT_OBJECT_DIRECTORY…​

[](https://git-scm.com/docs/git/fr#git-GITDEFAULTHASH) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITDEFAULTHASHcodespan)`GIT_DEFAULT_HASH`

Si cette variable est définie, l’algorithme d’empreinte par défaut pour les nouveaux dépôts sera défini à cette valeur. Cette valeur est ignorée lors du clonage et le réglage du dépôt distant est toujours utilisé. La valeur par défaut est "sha1". Voir `--object-format` dans [git-init[1]](https://git-scm.com/docs/git-init/fr).

[](https://git-scm.com/docs/git/fr#git-GITDEFAULTREFFORMAT) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITDEFAULTREFFORMATcodespan)`GIT_DEFAULT_REF_FORMAT`

Si cette variable est définie, le format du moteur de réferences par défaut pour les nouveaux dépôts sera défini à cette valeur. La valeur par défaut est "files". Voir `--ref-format` dans [git-init[1]](https://git-scm.com/docs/git-init/fr).
###  [](https://git-scm.com/docs/git/fr#_commits_git)Commits Git

[](https://git-scm.com/docs/git/fr#git-GITAUTHORNAME) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITAUTHORNAMEcodespan)`GIT_AUTHOR_NAME`

Le nom lisible utilisé dans l’identité de l’auteur lors de la création d’objets de commit ou d’étiquette, ou lors de l’écriture des reflogs. Surcharge les paramètres de configuration `user.name` et `author.name`.

[](https://git-scm.com/docs/git/fr#git-GITAUTHOREMAIL) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITAUTHOREMAILcodespan)`GIT_AUTHOR_EMAIL`

L’adresse courriel utilisée dans l’identité de l’auteur lors de la création d’objets commit ou étiquette, ou lors de l’écriture de reflogs. Surcharge les paramètres de configuration `user.email` et `author.email`.

[](https://git-scm.com/docs/git/fr#git-GITAUTHORDATE) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITAUTHORDATEcodespan)`GIT_AUTHOR_DATE`

La date utilisée pour l’identité de l’auteur lors de la création d’objets commit ou étiquette, ou lors de l’écriture de reflogs. Voir [git-commit[1]](https://git-scm.com/docs/git-commit/fr) pour les formats valides.

[](https://git-scm.com/docs/git/fr#git-GITCOMMITTERNAME) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITCOMMITTERNAMEcodespan)`GIT_COMMITTER_NAME`

Le nom lisible utilisé dans l’identité du validateur lors de la création d’objets commit ou étiquette, ou lors de l’écriture de reflogs. Surcharge les paramètres de configuration `user.name` et `committer.name`.

[](https://git-scm.com/docs/git/fr#git-GITCOMMITTEREMAIL) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITCOMMITTEREMAILcodespan)`GIT_COMMITTER_EMAIL`

L’adresse courriel utilisée dans l’identité de l’auteur lors de la création d’objets commit ou étiquette, ou lors de l’écriture de reflogs. Surcharge les paramètres de configuration `user.email` et `committer.email`.

[](https://git-scm.com/docs/git/fr#git-GITCOMMITTERDATE) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITCOMMITTERDATEcodespan)`GIT_COMMITTER_DATE`

La date utilisée pour l’identité du validateur lors de la création d’objets commit ou étiquette, ou lors de l’écriture de reflogs. Voir [git-commit[1]](https://git-scm.com/docs/git-commit/fr) pour les formats valides.

[](https://git-scm.com/docs/git/fr#git-EMAIL) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeEMAILcodespan)`EMAIL`

L’adresse de courriel utilisée dans les identités de l’auteur et du validateur si aucune autre variable d’environnement ou configuration pertinente n’a été définie.
###  [](https://git-scm.com/docs/git/fr#_diffs_git)Diffs Git

[](https://git-scm.com/docs/git/fr#git-GITDIFFOPTS) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITDIFFOPTScodespan)`GIT_DIFF_OPTS`

Seul le paramètre valide est "--unified=??" ou "-u??" pour définir le nombre de lignes de contexte affichées lors de la création d’une diff unifiée. Cela a préséance sur toute valeur d’option "-U" ou "--unified" passée sur la ligne de commande Git diff.

[](https://git-scm.com/docs/git/fr#git-GITEXTERNALDIFF) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITEXTERNALDIFFcodespan)`GIT_EXTERNAL_DIFF`

Lorsque la variable d’environnement `GIT_EXTERNAL_DIFF` est définie, le programme nommé par elle est appelé pour générer des diffs, et Git n’utilise pas sa machinerie de diff intégrée. Pour un chemin qui est ajouté, enlevé ou modifié, `GIT_EXTERNAL_DIFF` est appelé avec 7 paramètres :
```
chemin vieux-fichier vieux-hex vieux-mode nouveau-fichier nouveau-hex nouveau-mode
```

où :

[](https://git-scm.com/docs/git/fr#git-vieux-fichieretnouveau-fichier)vieux-fichier et nouveau-fichier

sont des fichiers que GIT_EXTERNAL_DIFF peut utiliser pour lire le contenu de vieux et nouveau

[](https://git-scm.com/docs/git/fr#git-vieux-hexetnouveau-hex)vieux-hex et nouveau-hex

sont les empreintes SHA-1 de 40 caractère hexadécimaux,

[](https://git-scm.com/docs/git/fr#git-vieux-modeetnouveau-mode)vieux-mode et nouveau-mode

sont la représentation octale des modes de fichiers.
Les paramètres de fichier peuvent indiquer le fichier de travail de l’utilisateur (par exemple `nouveau-fichier` dans "git-diff-files"), `/dev/null` (par exemple `vieux-fichier` quand un nouveau fichier est ajouté), ou un fichier temporaire (par exemple `vieux-fichier` dans l’index). `GIT_EXTERNAL_DIFF` n’a pas à se soucier de supprimer le fichier temporaire --il le sera quand `GIT_EXTERNAL_DIFF` se terminera.
Pour un chemin qui n’est pas fusionné, `GIT_EXTERNAL_DIFF` est appelé avec 1 paramètre, <chemin>.
Pour chaque chemin `GIT_EXTERNAL_DIFF` appelé, deux variables d`environnement, `GIT_DIFF_PATH_COUNTER` et `GIT_DIFF_PATH_TOTAL` sont définies.

[](https://git-scm.com/docs/git/fr#git-GITEXTERNALDIFFTRUSTEXITCODE) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITEXTERNALDIFFTRUSTEXITCODEcodespan)`GIT_EXTERNAL_DIFF_TRUST_EXIT_CODE`

If this Boolean environment variable is set to true then the `GIT_EXTERNAL_DIFF` command is expected to return exit code 0 if it considers the input files to be equal or 1 if it considers them to be different, like `diff`(`1`). If it is set to false, which is the default, then the command is expected to return exit code 0 regardless of equality. Any other exit code causes Git to report a fatal error.

[](https://git-scm.com/docs/git/fr#git-GITDIFFPATHCOUNTER) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITDIFFPATHCOUNTERcodespan)`GIT_DIFF_PATH_COUNTER`

Un compteur basé sur 1 incrémenté d’un pour chaque chemin.

[](https://git-scm.com/docs/git/fr#git-GITDIFFPATHTOTAL) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITDIFFPATHTOTALcodespan)`GIT_DIFF_PATH_TOTAL`

Le nombre total de chemins.
###  [](https://git-scm.com/docs/git/fr#_autre)autre

[](https://git-scm.com/docs/git/fr#git-GITMERGEVERBOSITY) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITMERGEVERBOSITYcodespan)`GIT_MERGE_VERBOSITY`

Un nombre contrôlant la quantité de production affichée par la stratégie de fusion récursive. Surcharge merge.verbosity. Voir [git-merge[1]](https://git-scm.com/docs/git-merge/fr)

[](https://git-scm.com/docs/git/fr#git-GITPAGER) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITPAGERcodespan)`GIT_PAGER`

Cette variable d’environnement remplace `$PAGER`. Si elle est définie à une chaîne vide ou à la valeur "cat", Git ne lancera pas de pager. Voir aussi l’option `core.pager` dans [git-config[1]](https://git-scm.com/docs/git-config/fr).

[](https://git-scm.com/docs/git/fr#git-GITPROGRESSDELAY) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITPROGRESSDELAYcodespan)`GIT_PROGRESS_DELAY`

Un nombre qui contrôle le nombre de secondes à retarder avant d’afficher des indicateurs de progrès optionnels. Valeur par défaut à 1.

[](https://git-scm.com/docs/git/fr#git-GITEDITOR) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITEDITORcodespan)`GIT_EDITOR`

Cette variable d’environnement remplace `$EDITOR` et `$VISUAL`. Elle est utilisée par plusieurs commandes Git lorsque, en mode interactif, un éditeur doit être lancé. Voir aussi [git-var[1]](https://git-scm.com/docs/git-var/fr) et l’option `core.editor` dans [git-config[1]](https://git-scm.com/docs/git-config/fr).

[](https://git-scm.com/docs/git/fr#git-GITSEQUENCEEDITOR) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITSEQUENCEEDITORcodespan)`GIT_SEQUENCE_EDITOR`

Cette variable d’environnement remplace l’éditeur Git configuré lors de l’édition de la liste de todo d’un rebasage interactif. Voir aussi [git-rebase[1]](https://git-scm.com/docs/git-rebase/fr) et l’option `sequence.editor` dans [git-config[1]](https://git-scm.com/docs/git-config/fr).

[](https://git-scm.com/docs/git/fr#git-GITSSH) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITSSHcodespan)`GIT_SSH`


[](https://git-scm.com/docs/git/fr#git-GITSSHCOMMAND) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITSSHCOMMANDcodespan)`GIT_SSH_COMMAND`

Si l’une de ces variables d’environnement est définie, _git fetch_ et _git push_ utiliseront la commande spécifiée au lieu de _ssh_ lorsqu’elles doivent se connecter à un système distant. Les paramètres de ligne de commande passés à la commande configurée sont déterminés par la variante de ssh. Voir l’option `ssh.variant` dans [git-config[1]](https://git-scm.com/docs/git-config/fr) pour plus de détails.
`$GIT_SSH_COMMAND` a priorité sur `$GIT_SSH`, et est interprété par le shell, ce qui permet d’inclure des arguments supplémentaires. ‘$GIT_SSH’ d’autre part doit être juste le chemin vers un programme (qui peut être un script shell d’emballage, si des arguments supplémentaires sont nécessaires).
Habituellement, il est plus facile de configurer toutes les options souhaitées à travers votre fichier `.ssh/config` personnel. Veuillez consulter votre documentation pour plus de détails.

[](https://git-scm.com/docs/git/fr#git-GITSSHVARIANT) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITSSHVARIANTcodespan)`GIT_SSH_VARIANT`

Si cette variable d’environnement est définie, elle remplace l’autodétection de Git pour définir si `GIT_SSH`/`GIT_SSH_COMMAND`/`core.sshCommand` se réfère à OpenSSH, plink ou tortoiseplink. Cette variable remplace le paramètre de configuration `ssh.variant` qui sert le même but.

[](https://git-scm.com/docs/git/fr#git-GITSSLNOVERIFY) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITSSLNOVERIFYcodespan)`GIT_SSL_NO_VERIFY`

Régler et exporter de cette variable d’environnement avec n’importe quelle valeur indique à Git de ne pas vérifier le certificat SSL lors de la récupération ou de la poussée sur HTTPS.

[](https://git-scm.com/docs/git/fr#git-GITATTRSOURCE) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITATTRSOURCEcodespan)`GIT_ATTR_SOURCE`

Définit l’arbre-esque dont gitattributes sera lu.

[](https://git-scm.com/docs/git/fr#git-GITASKPASS) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITASKPASScodespan)`GIT_ASKPASS`

Si cette variable d’environnement est définie, les commandes Git qui doivent acquérir des mots de passe ou des phrases de passe (p. ex. pour l’authentification HTTP ou IMAP) appellent ce programme avec un prompt approprié comme argument de ligne de commande et lisent le mot de passe de son STDOUT. Voir aussi l’option `core.askPass` dans [git-config[1]](https://git-scm.com/docs/git-config/fr).

[](https://git-scm.com/docs/git/fr#git-GITTERMINALPROMPT) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITTERMINALPROMPTcodespan)`GIT_TERMINAL_PROMPT`

Si cette variable d’environnement booléenne est définie à false, git ne posera pas de questions sur le terminal (p. ex., lors de la demande d’authentification HTTP).

[](https://git-scm.com/docs/git/fr#git-GITCONFIGGLOBAL) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITCONFIGGLOBALcodespan)`GIT_CONFIG_GLOBAL`


[](https://git-scm.com/docs/git/fr#git-GITCONFIGSYSTEM) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITCONFIGSYSTEMcodespan)`GIT_CONFIG_SYSTEM`

Prendre la configuration à partir des fichiers donnés au lieu des fichiers de configuration globaux ou au niveau système. Si `GIT_CONFIG_SYSTEM` est défini, le fichier de configuration du système défini au moment de la compilation (généralement `/etc/gitconfig`) ne sera pas lu. De même, si `GIT_CONFIG_GLOBAL` est défini, ni `$HOME/.gitconfig` ni `$XDG_CONFIG_HOME/git/config` ne seront pas lus. Peut être défini à `/dev/null` pour sauter les fichiers de configuration du niveau correspondant.

[](https://git-scm.com/docs/git/fr#git-GITCONFIGNOSYSTEM) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITCONFIGNOSYSTEMcodespan)`GIT_CONFIG_NOSYSTEM`

Indique qu’il faut sauter la lecture des paramètres du fichier au niveau système `$`(`prefix`)`/etc/gitconfig` . Cette variable d’environnement booléenne peut être utilisée avec `$HOME` et `$XDG_CONFIG_HOME` pour créer un environnement prévisible pour un script pointilleux, ou vous pouvez la définir à true pour éviter temporairement d’utiliser un fichier `/etc/gitconfig` buggé en attendant que quelqu’un avec suffisamment de permissions puisse le réparer.

[](https://git-scm.com/docs/git/fr#git-GITFLUSH) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITFLUSHcodespan)`GIT_FLUSH`

Si cette variable d’environnement est définie à "1", alors les commande telles que _git blame_ (en mode différentiel), _git rev-list_ , _git log_ , _git check-attr_ et _git check-ignore_ forceront un vidage du flux de sortie après que chaque enregistrement a été écrit. Si cette variable est définie à "0", la sortie de ces commandes sera faite en utilisant des E/S complètement tamponnés. Si cette variable d’environnement n’est pas réglée, Git choisira un vidage à chaque tampon ou à chaque enregistrement selon que stdout semble être redirigé vers un fichier ou non.

[](https://git-scm.com/docs/git/fr#git-GITTRACE) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITTRACEcodespan)`GIT_TRACE`

Active des messages généraux de trace, comme par exemple l’expansion d’alias, l’exécution de commandes intégrées et l’exécution de commandes externes.
Si cette variable est définie à "1, "2" ou "true" (la comparaison est insensible à la casse), les messages de trace seront imprimés sur stderr.
Si la variable est définie à une valeur entière supérieure à 2 et inférieure à 10 (strictement) alors Git interprétera cette valeur comme un descripteur de fichier ouvert et tentera d’écrire les messages de trace dans ce descripteur de fichier.
Sinon, si la variable est définie à un chemin absolu (démarrant avec un caractère _/_), Git l’interprétera comme un chemin de fichier et tentera d’y ajouter les messages de trace.
Désinitialiser la variable, ou la définir à vide, "0" ou "false" (casse insensible) désactive les messages de trace.

[](https://git-scm.com/docs/git/fr#git-GITTRACEFSMONITOR) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITTRACEFSMONITORcodespan)`GIT_TRACE_FSMONITOR`

Permet de tracer des messages pour l’extension de moniteur du système de fichiers. Voir `GIT_TRACE` pour les options de sortie de trace disponibles.

[](https://git-scm.com/docs/git/fr#git-GITTRACEPACKACCESS) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITTRACEPACKACCESScodespan)`GIT_TRACE_PACK_ACCESS`

Active la trace des messages pour tous les accès aux paquets. Pour chaque accès, le nom du fichier paquet et un décalage dans le paquet sont enregistrés. Cela peut être utile pour résoudre certains problèmes de performance liés aux paquets. Voir `GIT_TRACE` pour les options de sortie de trace disponibles.

[](https://git-scm.com/docs/git/fr#git-GITTRACEPACKET) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITTRACEPACKETcodespan)`GIT_TRACE_PACKET`

Active les messages de trace pour tous les paquets entrant ou sortant d’un programme donné. Cela peut aider à déboguer la négociation d’objets ou d’autres questions de protocole. Le traçage est désactivé dans un paquet commençant par "PACK" (mais voir `GIT_TRACE_PACKFILE` ci-dessous). Voir `GIT_TRACE` pour les options de sortie de trace disponibles.

[](https://git-scm.com/docs/git/fr#git-GITTRACEPACKFILE) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITTRACEPACKFILEcodespan)`GIT_TRACE_PACKFILE`

Active la trace des paquets envoyés ou reçus par un programme donné. Contrairement à d’autres sorties de trace, cette trace est verbatim : pas d’en-têtes, et pas de citation de données binaires. Vous voulez presque certainement diriger cette sortie dans un fichier (par exemple, `GIT_TRACE_PACKFILE=/tmp/mon.pack`) plutôt que de l’afficher sur le terminal ou de le mélanger avec d’autres sorties de trace.
Notez que ce n’est actuellement mis en œuvre que pour le côté client des clonages et des récupurations.

[](https://git-scm.com/docs/git/fr#git-GITTRACEPERFORMANCE) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITTRACEPERFORMANCEcodespan)`GIT_TRACE_PERFORMANCE`

Active les messages de trace liés à la performance, par exemple le temps d’exécution total de chaque commande Git. Voir `GIT_TRACE` pour les options de sortie de trace disponibles.

[](https://git-scm.com/docs/git/fr#git-GITTRACEREFS) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITTRACEREFScodespan)`GIT_TRACE_REFS`

Active les messages de trace pour les opérations sur la base de données de références. Voir `GIT_TRACE` pour les options de sortie de trace disponibles.

[](https://git-scm.com/docs/git/fr#git-GITTRACESETUP) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITTRACESETUPcodespan)`GIT_TRACE_SETUP`

Active les messages de trace .git, l’arbre de travail et le répertoire de travail courant après que Git a terminé sa phase de configuration. Voir `GIT_TRACE` pour les options de sortie de trace disponibles.

[](https://git-scm.com/docs/git/fr#git-GITTRACESHALLOW) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITTRACESHALLOWcodespan)`GIT_TRACE_SHALLOW`

Active les messages de trace qui peuvent aider à déboguer des récupérations / clonage de dépôts superficiels. Voir `GIT_TRACE` pour les options de sortie de trace disponibles.

[](https://git-scm.com/docs/git/fr#git-GITTRACECURL) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITTRACECURLcodespan)`GIT_TRACE_CURL`

Permet un traçage complet par curl de toutes les données entrantes et sortantes, y compris les informations descriptives, du protocole de transport git. Ceci est similaire à faire du curl `--trace-ascii` sur la ligne de commande. Voir `GIT_TRACE` pour les options de sortie de trace disponibles.

[](https://git-scm.com/docs/git/fr#git-GITTRACECURLNODATA) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITTRACECURLNODATAcodespan)`GIT_TRACE_CURL_NO_DATA`

Lorsqu’une trace de curl est activée (voir `GIT_TRACE_CURL` ci-dessus), ne pas décharger les données (c’est-à-dire que seules les lignes d’info et les en-têtes sont tracés).

[](https://git-scm.com/docs/git/fr#git-GITTRACE2) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITTRACE2codespan)`GIT_TRACE2`

Active des messages de trace plus détaillés par la bibliothèque "trace2". La sortie de `GIT_TRACE2` est un simple format texte pour consommation humaine.
Si cette variable est définie à "1, "2" ou "true" (la comparaison est insensible à la casse), les messages de trace seront imprimés sur stderr.
Si la variable est définie à une valeur entière supérieure à 2 et inférieure à 10 (strictement) alors Git interprétera cette valeur comme un descripteur de fichier ouvert et tentera d’écrire les messages de trace dans ce descripteur de fichier.
Sinon, si la variable est définie à un chemin absolu (démarrant avec un caractère _/_), Git l’interprétera comme un chemin de fichier et tentera d’y ajouter les messages de trace. Si le chemin existe déjà et est un répertoire, les messages de trace seront écrits sur des fichiers (un par processus) dans ce répertoire, nommés selon le dernier composant du SID et un compteur optionnel (pour éviter les collisions de nom de fichier).
En outre, si la variable est définie à _af_unix:[ <type-de-socket>]<chemin-absolu>, Git va essayer d'ouvrir le chemin en tant que socket de domaine Unix. Le type de socket peut être soit `stream_ ou `dgram`.
Désinitialiser la variable, ou la définir à vide, "0" ou "false" (casse insensible) désactive les messages de trace.
Voir la [ documentation de Trace2](https://git-scm.com/docs/api-trace2/fr) pour tous les détails.

[](https://git-scm.com/docs/git/fr#git-GITTRACE2EVENT) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITTRACE2EVENTcodespan)`GIT_TRACE2_EVENT`

Ce réglage écrit un format JSON adapté à l’interprétation automatique. Voir `GIT_TRACE2` pour les options de sortie de trace disponibles et la [documentation de Trace2](https://git-scm.com/docs/api-trace2/fr) pour tous les détails.

[](https://git-scm.com/docs/git/fr#git-GITTRACE2PERF) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITTRACE2PERFcodespan)`GIT_TRACE2_PERF`

En plus des messages texte disponibles dans `GIT_TRACE2`, ce paramètre écrit un format à colonne pour comprendre les régions de nidification. Voir `GIT_TRACE2` pour les options de sortie de trace disponibles et la [documentation de Trace2](https://git-scm.com/docs/api-trace2/fr) pour tous les détails.

[](https://git-scm.com/docs/git/fr#git-GITTRACEREDACT) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITTRACEREDACTcodespan)`GIT_TRACE_REDACT`

Par défaut, lorsque le traçage est activé, Git caviarde les valeurs des cookies, l’en-tête "Authorization:", l’en-tête "Proxy-Authorization:" et les URIs de paquets. Définissez cette variable d’environnement booléenne à false pour empêcher ce caviardage.

[](https://git-scm.com/docs/git/fr#git-GITNOREPLACEOBJECTS) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITNOREPLACEOBJECTScodespan)`GIT_NO_REPLACE_OBJECTS`

Régler et exporter cette variable d’environnement indique à Git d’ignorer les réfs de remplacement et de ne pas remplacer les objets Git.

[](https://git-scm.com/docs/git/fr#git-GITLITERALPATHSPECS) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITLITERALPATHSPECScodespan)`GIT_LITERAL_PATHSPECS`

Régler cette variable d’environnement booléenne à true va forcer Git à traiter tous les spécificateurs de chemin littéralement, plutôt que comme des motifs glob. Par exemple, exécuter _GIT_LITERAL_PATHSPECS=1 git log -- `\\*.c_ cherchera des commits qui touchent le chemin `*.c`, pas des chemins auquels le glob `*.c` correspond. Vous pourriez vouloir cela si vous fournissez des chemins littéraux vers Git (p. ex., des chemins précédemment donnés par `git` `ls-tree`, `--raw` sortie diff, etc.).

[](https://git-scm.com/docs/git/fr#git-GITGLOBPATHSPECS) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITGLOBPATHSPECScodespan)`GIT_GLOB_PATHSPECS`

Régler cette variable d’environnement booléenne à true va indiquer à Git de traiter tous les spécificateurs de chemin comme des motifs glob (aka magie "glob").

[](https://git-scm.com/docs/git/fr#git-GITNOGLOBPATHSPECS) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITNOGLOBPATHSPECScodespan)`GIT_NOGLOB_PATHSPECS`

Régler cette variable d’environnement booléenne à vrai indique à Git de traiter tous les spécificateurs de chemin comme littéral (aka magie "littérale").

[](https://git-scm.com/docs/git/fr#git-GITICASEPATHSPECS) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITICASEPATHSPECScodespan)`GIT_ICASE_PATHSPECS`

Régler cette variable d’environnement booléenne à true va indiquer à Git de traiter tous les spécificateurs de chemins comme insensibles à la casse.

[](https://git-scm.com/docs/git/fr#git-GITNOLAZYFETCH) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITNOLAZYFETCHcodespan)`GIT_NO_LAZY_FETCH`

Régler cette variable d’environnement booléenne à true va indiquer à Git de ne pas récupérer à la demande les objets manquants depuis le distant prometteur.

[](https://git-scm.com/docs/git/fr#git-GITREFLOGACTION) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITREFLOGACTIONcodespan)`GIT_REFLOG_ACTION`

Lorsqu’une réf est mis à jour, des entrées de reflog sont créées pour suivre la raison pour laquelle la réf a été mise à jour (ce qui est généralement le nom de la commande de haut niveau qui a mis à jour la réf), en plus des anciennes et nouvelles valeurs de la réf. Une commande scriptée de porcelaine peut utiliser la fonction set_reflog_action helper dans `git-sh-setup` pour définir son nom à cette variable lorsqu’elle est invoquée comme commande de niveau supérieur par l’utilisateur final, pour l’enregistrer dans le corps du reflog.

[](https://git-scm.com/docs/git/fr#git-GITREFPARANOIA) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITREFPARANOIAcodespan)`GIT_REF_PARANOIA`

Si cette variable d’environnement booléenne est définie à false, ignorer les réfs cassées ou mal nommées lors de l’itération sur les listes de réfs. Habituellement, Git tentera d’inclure tous ces réfs, ce qui peut entraîner l’échec de certaines opérations. Cela est généralement préférable, car il vaut mieux abandonner les opérations potentiellement destructrices (par exemple, [git-prune[1]](https://git-scm.com/docs/git-prune/fr)) plutôt que d’ignorer les réfs cassées (et donc considérer l’histoire qu’elles pointent comme inutiles à sauver). La valeur par défaut est `1` (c’est-à-dire être paranoïaque sur la détection et abandon de toutes les opérations). Vous ne devriez normalement pas avoir besoin de définir ceci à `0`, mais ceci peut être utile quand vous essayez de sauver des données d’un dépôt corrompu.

[](https://git-scm.com/docs/git/fr#git-GITCOMMITGRAPHPARANOIA) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITCOMMITGRAPHPARANOIAcodespan)`GIT_COMMIT_GRAPH_PARANOIA`

When loading a commit object from the commit-graph, Git performs an existence check on the object in the object database. This is done to avoid issues with stale commit-graphs that contain references to already-deleted commits, but comes with a performance penalty.
The default is "false", which disables the aforementioned behavior. Setting this to "true" enables the existence check so that stale commits will never be returned from the commit-graph at the cost of performance.

[](https://git-scm.com/docs/git/fr#git-GITALLOWPROTOCOL) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITALLOWPROTOCOLcodespan)`GIT_ALLOW_PROTOCOL`

Si elle est définie comme une liste de protocoles séparés par des deux-points, se comporter comme si `protocol.allow` est défini à `never` , et définit `protocol.`_< nom>_`.allow` de chacun des protocoles énumérés à `always`(ce qui surcharge toute configuration existante). Voir la description de `protocol.allow` dans [git-config[1]](https://git-scm.com/docs/git-config/fr) pour plus de détails.

[](https://git-scm.com/docs/git/fr#git-GITPROTOCOLFROMUSER) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITPROTOCOLFROMUSERcodespan)`GIT_PROTOCOL_FROM_USER`

Définir cette variable d’environnement booléenne à false pour empêcher les protocoles utilisés par fetch/push/clone qui sont configurés à l’état `utilisateur`. Ceci est utile pour limiter l’initialisation récursive des sous-modules à partir d’un dépôt non fiable ou pour des programmes qui fournissentdes URLS potentiellement non fiables aux commandes git. Voir [git-config[1]](https://git-scm.com/docs/git-config/fr) pour plus de détails.

[](https://git-scm.com/docs/git/fr#git-GITPROTOCOL) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITPROTOCOLcodespan)`GIT_PROTOCOL`

Pour usage interne seulement. Utilisé pour établir la liaison en protocole filaire. Contient une liste séparée par deux-point _:_ des clés avec des valeurs facultatives _< clé>[=<valeur>]_. La présence de clés et de valeurs inconnues doit être ignorée.
Notez que les serveurs peuvent devoir être configurés pour permettre à cette variable de passer sur certains transports. Elle sera propagée automatiquement lors de l’accès aux dépôts locaux (c’est-à-dire _file:// ' ou un chemin de système de fichiers), ainsi que via le protocole `git://_. Pour git-over-http, elle devrait fonctionner automatiquement dans la plupart des configurations, mais voir la discussion dans [git-http-backend[1]](https://git-scm.com/docs/git-http-backend/fr). Pour git-over-ssh, le serveur ssh peut être configuré pour permettre aux clients de passer cette variable (par exemple, en utilisant `AcceptEnv` `GIT_PROTOCOL` avec OpenSSH).
Cette configuration est facultative. Si la variable n’est pas propagée, les clients retomberont sur le protocole original "v0" (mais ils peuvent manquer certaines améliorations ou caractéristiques de performance). Cette variable n’affecte actuellement que les clonages et les récupérations ; elle n’est pas encore utilisée pour les poussées (mais peut-être à l’avenir).

[](https://git-scm.com/docs/git/fr#git-GITOPTIONALLOCKS) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITOPTIONALLOCKScodespan)`GIT_OPTIONAL_LOCKS`

Si cette variable d’environnement booléenne est définie à false, Git effectuera toute opération demandée sans effectuer de sous-opérations facultatives qui nécessitent un verrouillage. Par exemple, cela empêchera `git` `status` de rafraîchir l’index comme effet secondaire. Ceci est utile pour les processus fonctionnant en arrière-plan qui ne veulent pas provoquer la contention de verrouillage avec d’autres opérations sur le dépôt. Par défaut à `1`.

[](https://git-scm.com/docs/git/fr#git-GITREDIRECTSTDIN) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITREDIRECTSTDINcodespan)`GIT_REDIRECT_STDIN`


[](https://git-scm.com/docs/git/fr#git-GITREDIRECTSTDOUT) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITREDIRECTSTDOUTcodespan)`GIT_REDIRECT_STDOUT`


[](https://git-scm.com/docs/git/fr#git-GITREDIRECTSTDERR) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITREDIRECTSTDERRcodespan)`GIT_REDIRECT_STDERR`

Windows seulement : permettre de rediriger les sockets standard d’entrée/sortie/erreur sur les chemins spécifiés par les variables d’environnement. Ceci est particulièrement utile dans les applications multithread où le moyen canonique de passer les poignées standard via `CreateProcess`() n’est pas possible parce qu’il exigerait que les poignées soient héritées (et par conséquent *chaque processus démarré en hériterait, en bloquant éventuellement les opérations régulières de Git). Le principal cas d’utilisation prévu est d’utiliser des tuyaux nommés pour la communication (par exemple _\\\\.\pipe\mon-git-stdin-123_).
Deux valeurs spéciales sont supportées : `off` va tout simplement fermer la poignée standard correspondante, et si `GIT_REDIRECT_STDERR` est _2 >&1_, l’erreur standard sera redirigée vers la même poignée que la sortie standard.

[](https://git-scm.com/docs/git/fr#git-GITPRINTSHA1ELLIPSISobsolte) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITPRINTSHA1ELLIPSIScodespanobsolte)`GIT_PRINT_SHA1_ELLIPSIS` (obsolète)

Si elle est définie à `oui`, afficher une ellipse suivant une valeur SHA-1 (abrégée). Cela affecte les indications des HEAD détachées ([git-checkout[1]](https://git-scm.com/docs/git-checkout/fr)) et la sortie diff brute ([git-diff[1]](https://git-scm.com/docs/git-diff/fr)). L’impression d’une ellipse dans les cas mentionnés n’est plus considérée comme adéquate et la gestion est susceptible d’être retirée dans un avenir prévisible (ainsi que la variable).

[](https://git-scm.com/docs/git/fr#git-GITADVICE) [](https://git-scm.com/docs/git/fr#git-spanclasssynopsiscodeGITADVICEcodespan)`GIT_ADVICE`

If set to `0`, then disable all advice messages. These messages are intended to provide hints to human users that may help them get out of problematic situations or take advantage of new features. Users can disable individual messages using the `advice.*` config keys. These messages may be disruptive to tools that execute Git processes, so this variable is available to disable the messages. (The `--no-advice` global option is also available, but old Git versions may fail when this option is not understood. The environment variable will be ignored by Git versions that do not understand it.)
##  [](https://git-scm.com/docs/git/fr#_discussion)Discussion]
Plus de détails sur ce qui suit sont disponibles dans le [chapitre des concepts Git du manuel utilisateur](https://git-scm.com/docs/user-manual/fr#git-concepts) et [gitcore-tutorial[7]](https://git-scm.com/docs/gitcore-tutorial/fr).
Un projet Git se compose normalement d’un répertoire de travail avec un sous-répertoire ".git" au niveau supérieur. Le répertoire .git contient, entre autres, une base de données d’objets compressés représentant l’historique complet du projet, un fichier "index" qui relie l’historique au contenu actuel de l’arbre de travail, et des pointeurs nommés dans cet historique comme les étiquettes et les sommets de branche.
La base de données d’objets contient des objets de trois types principaux : les blobs, qui contiennent des données de fichiers ; les arbres, qui pointent vers des blobs et d’autres arbres pour construire des hiérarchies de répertoires ; et les commits, qui référencent chacun un seul arbre et un certain nombre de commits parents.
Le commit, équivalent à ce que d’autres systèmes appellent un « changeset » ou une « version », représente une étape dans l’historique du projet, et chaque parent représente une étape immédiatement antérieure. Les commits avec plus d’un parent représentent des fusions de lignes de développement indépendantes.
Tous les objets sont nommés par l’empreinte SHA-1 de leur contenu, normalement écrite comme une chaîne de 40 chiffres hexadécimaux. De tels noms sont uniques à chaque objet. Tout l’historique menant à un commit peut être validé en signant seulement ce commit. Un quatrième type d’objet, l’étiquette, existe à cette fin.
Lors de la première création, les objets sont stockés dans des fichiers individuels, mais peuvent plus tard être compressés ensemble dans des « fichiers paquet » pour plus d’efficacité .
Les pointeurs nommés appelés réfs marquent des points intéressants dans l’historique. Une réf peut contenir le nom SHA-1 d’un objet ou le nom d’une autre réf (cette dernière est appelée une "réf symbolique"). Les réfs avec des noms commençant `refs/head/` contiennent le nom SHA-1 du commit le plus récent (ou "head") d’une branche en développement. Les noms SHA-1 des étiquettes intéressantes sont stockés sous `refs/tags/`. Une réf symbolique nommée `HEAD` contient le nom de la branche actuellement extraite.
Le fichier index est initialisé avec une liste de tous les chemins et, pour chaque chemin, un objet blob et un ensemble d’attributs. L’objet blob représente le contenu du fichier à la tête de la branche actuelle. Les attributs (dernière date de modification, taille, etc.) sont prélevés sur le fichier correspondant de l’arbre de travail. Les modifications subséquentes à l’arbre de travail peuvent être trouvées en comparant ces attributs. L’index peut être mis à jour avec de nouveaux contenus, et de nouveaux commits peuvent être créés à partir du contenu stocké dans l’index.
L’index est également capable de stocker plusieurs entrées (appelées « étapes ») pour un nom de chemin donné. Ces étapes sont utilisées pour contenir les différentes versions non fusionnées d’un fichier lorsqu’une fusion est en cours.
##  [](https://git-scm.com/docs/git/fr#_s%C3%A9curit%C3%A9)SÉCURITÉ
Some configuration options and hook files may cause Git to run arbitrary shell commands. Because configuration and hooks are not copied using `git` `clone`, it is generally safe to clone remote repositories with untrusted content, inspect them with `git` `log`, and so on.
However, it is not safe to run Git commands in a `.git` directory (or the working tree that surrounds it) when that `.git` directory itself comes from an untrusted source. The commands in its config and hooks are executed in the usual way.
By default, Git will refuse to run when the repository is owned by someone other than the user running the command. See the entry for `safe.directory` in [git-config[1]](https://git-scm.com/docs/git-config/fr). While this can help protect you in a multi-user environment, note that you can also acquire untrusted repositories that are owned by you (for example, if you extract a zip file or tarball from an untrusted source). In such cases, you’d need to "sanitize" the untrusted repository first.
If you have an untrusted `.git` directory, you should first clone it with `git` `clone` `--no-local` to obtain a clean copy. Git does restrict the set of options and hooks that will be run by `upload-pack`, which handles the server side of a clone or fetch, but beware that the surface area for attack against `upload-pack` is large, so this does carry some risk. The safest thing is to serve the repository as an unprivileged user (either via [git-daemon[1]](https://git-scm.com/docs/git-daemon/fr), ssh, or using other tools to change user ids). See the discussion in the `SECURITY` section of [git-upload-pack[1]](https://git-scm.com/docs/git-upload-pack/fr).
##  [](https://git-scm.com/docs/git/fr#_documentation_suppl%C3%A9mentaire)DOCUMENTATION SUPPLÉMENTAIRE
Voir les références dans la section "description" pour commencer à utiliser Git. Ce qui suit est probablement plus détaillé que nécessaire pour un utilisateur débutant.
Le [chapitre Concepts Git du manuel d’utilisateur](https://git-scm.com/docs/user-manual/fr#git-concepts) and [gitcore-tutorial[7]](https://git-scm.com/docs/gitcore-tutorial/fr) fournissent tout deux des introductions à l’architecture sous-jacente de Git.
Voir [gitworkflows[7]](https://git-scm.com/docs/gitworkflows/fr) pour un aperçu des modes de travail recommandés.
Voir aussi les documents de [howto](https://git-scm.com/docs/howto-index/fr) pour quelques exemples utiles.
Le fonctionnement interne est documenté dans la [documentation d’API de Git](https://git-scm.com/docs/api-index/fr).
Les utilisateurs qui migrent depuis CVS peuvent également vouloir lire [gitcvs-migration[7]](https://git-scm.com/docs/gitcvs-migration/fr).
##  [](https://git-scm.com/docs/git/fr#_auteurs)Auteurs
Git a été initialement développé par Linus Torvalds, et est actuellement maintenu par Junio C Hamano. De nombreuses contributions proviennent de la liste de diffusion de Git <git@vger.kernel.org>. <https://openhub.net/p/git/contributors/summary> vous donne une liste plus complète des contributeurs.
Si vous avez un clone de git.git lui-même, la sortie de [git-shortlog[1]](https://git-scm.com/docs/git-shortlog/fr) et [git-blame[1]](https://git-scm.com/docs/git-blame/fr) peut vous montrer les auteurs pour des parties spécifiques du projet.
##  [](https://git-scm.com/docs/git/fr#_signaler_des_bogues)Signaler des bogues
Signaler des bogues à la liste de diffusion de Git <git@vger.kernel.org> où le développement et la maintenance sont principalement effectués. Vous n’avez pas à être abonné à la liste pour y envoyer un message. Voir l’archive de la liste à l’adresse <https://lore.kernel.org/git> pour les précédents rapports sur les bogues et autres débats.
Les questions de sécurité pertinentes devraient être divulguées en privé à la liste de diffusion de Sécurité Git <git-security@googlegroups.com>.
##  [](https://git-scm.com/docs/git/fr#_voir_aussi)VOIR AUSSI
[gittutorial[7]](https://git-scm.com/docs/gittutorial/fr), [gittutorial-2[7]](https://git-scm.com/docs/gittutorial-2/fr), [giteveryday[7]](https://git-scm.com/docs/giteveryday/fr), [gitcvs-migration[7]](https://git-scm.com/docs/gitcvs-migration/fr), [gitglossary[7]](https://git-scm.com/docs/gitglossary/fr), [gitcore-tutorial[7]](https://git-scm.com/docs/gitcore-tutorial/fr), [gitcli[7]](https://git-scm.com/docs/gitcli/fr), [Manuel de l’utilisateur de Git](https://git-scm.com/docs/user-manual/fr), [gitworkflows[7]](https://git-scm.com/docs/gitworkflows/fr)
##  [](https://git-scm.com/docs/git/fr#_git)GIT
Fait partie de la suite [git[1]](https://git-scm.com/docs/git/fr)
##  [](https://git-scm.com/docs/git/fr#_traduction)TRADUCTION
Cette page de manuel a été traduite par Jean-Noël Avila <jn.avila AT free DOT fr> et les membres du projet git-manpages-l10n. Veuillez signaler toute erreur de traduction par un rapport de bogue sur le site <https://github.com/jnavila/git-manpages-l10n> .
[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
